@@ -7,25 +7,25 @@ from .errors import ErrorCodeEnum, LegacyErrorCodeEnum
 
 
 class RcsSMSBody(BaseModel):
-    title: str = Field(max_length=30)
+    title: Optional[str] = Field(max_length=30)
     description: str = Field(max_length=100)
     # TODO: media:
 
 
 class RcsLMSBody(BaseModel):
-    title: str = Field(max_length=30)
+    title: Optional[str] = Field(max_length=30)
     description: str = Field(max_length=1300)
     # TODO: media:
 
 
 class RcsMMSBody(BaseModel):
-    title: str = Field(max_length=30)
+    title: Optional[str] = Field(max_length=30)
     description: str = Field(max_length=1300)
     # TODO: media:
 
 
 class RcsCHATBody(BaseModel):
-    title: str = Field(max_length=30)
+    title: Optional[str] = Field(max_length=30)
     description: str = Field(max_length=1300)
     # TODO: media:
 
@@ -133,6 +133,12 @@ class PostbackInfo(BaseModel):
 
 class ActionInfo(BaseModel):
     urlAction: Optional[UrlActionInfo]
+    localBrowserAction: Optional[LocalBrowserActionInfo]
+    mapAction: Optional[MapActionInfo]
+    calendarAction: Optional[CalendarActionInfo]
+    clipboardAction: Optional[ClipboardActionInfo]
+    composeAction: Optional[ComposeActionInfo]
+    dialerAction: Optional[DialerActionInfo]
     displayText: str = Field(max_length=200)
     postback: PostbackInfo
 
@@ -171,7 +177,7 @@ class RcsInfo(BaseModel):
     * Agency ID는 "Rcs Biz Center - 브랜드 운영관리" 에서 기업의 브랜드가 대행사 권한을 부여한 대행사의 ID
     Agency ID가 "ktbizrcs" 가 아닌 경우 필수 입력 필요.
     """
-    messagebaseId: str = Field(max_length=40)
+    messagebaseId: enums.MessageEnum
     serviceType: enums.ServiceTypeEnum
     expiryOption: Optional[enums.ExpiryOptionEnum]
     """
